cfitall :: configure it all
===========================

cfitall (configure it all) is a configuration management library for
python applications.

Please see `Read The Docs <https://cfitall.readthedocs.io/en/latest/>`__.
